@@ -7,7 +7,7 @@ require DynaLoader;
 @ISA = qw(Exporter DynaLoader);
 @EXPORT = ();
 
-$VERSION = '1.3.4';
+$VERSION = '1.4.3';
 
 bootstrap Quota;
 
@@ -65,8 +65,10 @@ sub getqcarg {
 	else                       { $ret = $path }     #($argtyp eq "mntpt")
 
         # XFS, VxFS and AFS quotas require separate access methods
+        # (optional for VxFS: later versions use 'normal' quota interface)
         if   (($fstyp eq "xfs") && ($fsupp =~ /,XFS/)) { $ret = "(XFS)$ret" }
-        elsif(($fstyp eq "vxfs") && ($fsupp =~ /,VXFS/)) { $ret = "(VXFS)$ret" }
+        elsif(($fstyp eq "vxfs") &&
+              defined($fsupp) && ($fsupp =~ /,VXFS/)) { $ret = "(VXFS)$ret" }
         elsif((($fstyp eq "afs") || ($fsname eq "AFS")) &&
               ($fsupp =~ /,AFS/)) { $ret = "(AFS)$target"; }
         last;
@@ -117,14 +119,14 @@ Quota - Perl interface to file system quotas
 
     ($block_curr, $block_soft, $block_hard, $block_timelimit,
      $inode_curr, $inode_soft, $inode_hard, $inode_timelimit) =
-    Quota::query($dev [,$uid]);
+    Quota::query($dev [,$uid [,isgrp]]);
 
     ($block_curr, $block_soft, $block_hard, $block_timelimit,
      $inode_curr, $inode_soft, $inode_hard, $inode_timelimit) =
     Quota::rpcquery($host, $path [,$uid]);
 
     Quota::setqlim($dev, $uid, $block_soft, $block_hard,
-		   $inode_soft, $inode_hard [,$tlo]);
+		   $inode_soft, $inode_hard [,$tlo [,isgrp]]);
 
     Quota::sync([$dev]);
 
@@ -220,6 +222,10 @@ The main purpose of this function is to check if quota is enabled
 in the kernel and for a particular file system. Read the B<quotaon(1m)>
 man page on how to enable quotas on a file system.
 
+Note: on some systems this function always returns a success indication,
+even on partitions which do not have quotas enabled (e.g. Linux 2.4).
+This is not a bug in this module; it's a limitation in certain kernels.
+
 =item I<($bc,$bs,$bh,$bt, $ic,$is,$ih,$it) =>
 
 I<Quota::rpcquery($host,$path,$uid)>
@@ -286,13 +292,16 @@ use this function to output error messages, since the normal messages
 don't always make sense for quota errors
 (e.g. I<ESRCH>: B<No such process>, here: B<No quota for this user>)
 
+Note that this function only returns a defined result if you called a
+Quota command directly before which returned an error indication.
+
 =head1 RETURN VALUES
 
 Functions that are supposed return lists or scalars, return I<undef> upon
 errors. As usual B<$!> contains the error code (see B<Quota::strerr>).
 
-B<Quota::endmntent> always returns I<undef>. All other functions return
-I<undef> only upon errors.
+B<Quota::endmntent> always returns I<undef>.
+All other functions return 0 upon success, non-zero integer otherwise.
 
 =head1 EXAMPLES
 
@@ -302,19 +311,17 @@ some longer scripts, kindly donated by users of the module.
 
 =head1 BUGS
 
-With remote quotas we have to rely on the remote system to state
-correctly which block size the quota values are referring to.
-Unfortunately on Linux the rpc.rquotad reports a block size of
-4 kilobytes, which is wildly incorrect. So you either need to fix
-your Linux rquotad or keep B<#define LINUX_RQUOTAD_BUG> defined,
-which will Quota::query always let assume all remote partners
-in reality report 1kB blocks. Of course that'll break with mixed
-systems, so better fix your rquotad. For more info on other Linux
-bugs please see INSTALL.
+With remote quotas we have to rely on the remote system to
+state correctly which block size the quota values are
+referring to. Old versions of the Linux rpc.rquotad
+reported a block size of 4 kilobytes, which was wildly
+incorrect. For more info on this and other Linux bugs please
+see INSTALL.
 
 =head1 AUTHORS
 
-This module was created 1995 by Tom Zoerner (tomzo@nefkom.net)
+This module was created 1995 by Tom Zoerner
+(email: tomzo AT nefkom DOT net)
 and since then continually improved and ported to
 many operating- and file-systems. Numerous people
 have contributed to this process; for a complete
